EXPORTS
	??0RPeninputServer@@QAE@XZ @ 1 NONAME ; RPeninputServer::RPeninputServer(void)
	?ActivateLayout@RPeninputServer@@QAEXH@Z @ 2 NONAME ; void RPeninputServer::ActivateLayout(int)
	?AddPeninputServerObserverL@RPeninputServer@@QAEXPAVMPeninputServerEventHandler@@@Z @ 3 NONAME ; void RPeninputServer::AddPeninputServerObserverL(class MPeninputServerEventHandler *)
	?ClearServerEvent@RPeninputServer@@QAEXXZ @ 4 NONAME ; void RPeninputServer::ClearServerEvent(void)
	?Close@RPeninputServer@@QAEXXZ @ 5 NONAME ; void RPeninputServer::Close(void)
	?Connect@RPeninputServer@@QAEHXZ @ 6 NONAME ; int RPeninputServer::Connect(void)
	?GetEditorMaxLength@RPeninputServer@@QAEHXZ @ 7 NONAME ABSENT ; int RPeninputServer::GetEditorMaxLength(void)
	?GetServerEventData@RPeninputServer@@QAEHAAVTDes16@@@Z @ 8 NONAME ; int RPeninputServer::GetServerEventData(class TDes16 &)
	?HandleCommand@RPeninputServer@@QAEHH@Z @ 9 NONAME ; int RPeninputServer::HandleCommand(int)
	?HandleCommand@RPeninputServer@@QAEHHABVTDesC8@@@Z @ 10 NONAME ; int RPeninputServer::HandleCommand(int, class TDesC8 const &)
	?IsVisible@RPeninputServer@@QAEHXZ @ 11 NONAME ; int RPeninputServer::IsVisible(void)
	?RemovePeninputServerObserver@RPeninputServer@@QAEXXZ @ 12 NONAME ; void RPeninputServer::RemovePeninputServerObserver(void)
	?ResourceChanged@RPeninputServer@@QAEXH@Z @ 13 NONAME ; void RPeninputServer::ResourceChanged(int)
	?SendFepAwareEditorText@RPeninputServer@@QAEXABUTFepInputContextFieldData@@@Z @ 14 NONAME ABSENT ; void RPeninputServer::SendFepAwareEditorText(struct TFepInputContextFieldData const &)
	?ServerEventDataNum@RPeninputServer@@QAEHXZ @ 15 NONAME ; int RPeninputServer::ServerEventDataNum(void)
	?SetDisplayMode@RPeninputServer@@QAEXW4TDisplayMode@@0@Z @ 16 NONAME ; void RPeninputServer::SetDisplayMode(enum TDisplayMode, enum TDisplayMode)
	?SetUiLayoutId@RPeninputServer@@QAEHVTUid@@@Z @ 17 NONAME ; int RPeninputServer::SetUiLayoutId(class TUid)
	?SetUiLayoutId@RPeninputServer@@QAEHVTUid@@ABVTDesC8@@@Z @ 18 NONAME ; int RPeninputServer::SetUiLayoutId(class TUid, class TDesC8 const &)
	?SetUiLayoutPos@RPeninputServer@@QAEHABVTPoint@@@Z @ 19 NONAME ; int RPeninputServer::SetUiLayoutPos(class TPoint const &)
	?UiLayoutPos@RPeninputServer@@QAE?AVTPoint@@XZ @ 20 NONAME ; class TPoint RPeninputServer::UiLayoutPos(void)
	?Version@RPeninputServer@@QBE?AVTVersion@@XZ @ 21 NONAME ; class TVersion RPeninputServer::Version(void) const
	?GetImePluginIdListL@RPeninputServer@@QAEXHHAAV?$RArray@H@@@Z @ 22 NONAME ; void RPeninputServer::GetImePluginIdListL(int, int, class RArray<int> &)
	?PenSupportLanguagesL@RPeninputServer@@QAEXAAV?$RArray@H@@@Z @ 23 NONAME ; void RPeninputServer::PenSupportLanguagesL(class RArray<int> &)
	?IsForeground@RPeninputServer@@QAEHXZ @ 24 NONAME ; int RPeninputServer::IsForeground(void)
	?SetForeground@RPeninputServer@@QAEHH@Z @ 25 NONAME ; TBool RPeninputServer::SetForeground(TBool)  
	?AddPenUiActivationHandler@RPeninputServer@@QAEHPAVMPenUiActivationHandler@@H@Z @ 26 NONAME
	?RemovePenUiActivationHandler@RPeninputServer@@QAEXXZ @ 27 NONAME ; void RPeninputServer::RemovePenUiActivationHandler(void)
	??1CPenInputServerHandler@@UAE@XZ @ 28 NONAME ; CPenInputServerHandler::~CPenInputServerHandler(void)
	?ActivateUiLayout@CPenInputServerHandler@@QAEXH@Z @ 29 NONAME ; void CPenInputServerHandler::ActivateUiLayout(int)
	?ConnectServer@CPenInputServerHandler@@QAEHXZ @ 30 NONAME ; int CPenInputServerHandler::ConnectServer(void)
	?DisconnectServer@CPenInputServerHandler@@QAEXXZ @ 31 NONAME ; void CPenInputServerHandler::DisconnectServer(void)
	?HandleCommand@RPeninputServer@@QAEHHABVTDesC8@@AAH@Z @ 32 NONAME ; int RPeninputServer::HandleCommand(int, class TDesC8 const &, int &)
	?NewL@CPenInputServerHandler@@SAPAV1@XZ @ 33 NONAME ; class CPenInputServerHandler * CPenInputServerHandler::NewL(void)
	?SendCommandToServer@CPenInputServerHandler@@QAEXH@Z @ 34 NONAME ; void CPenInputServerHandler::SendCommandToServer(int)
	?SendCommandToServer@CPenInputServerHandler@@QAEXHABVTDesC16@@@Z @ 35 NONAME ; void CPenInputServerHandler::SendCommandToServer(int, class TDesC16 const &)
	?SendCommandToServer@CPenInputServerHandler@@QAEXHH@Z @ 36 NONAME ; void CPenInputServerHandler::SendCommandToServer(int, int)
	?SendNewKeyToServer@CPenInputServerHandler@@QAEXHABUTItutKey@@@Z @ 37 NONAME ; void CPenInputServerHandler::SendNewKeyToServer(int, struct TItutKey const &)
	?SendPromptTextToServer@CPenInputServerHandler@@QAEXHABUTFepPromptText@@@Z @ 38 NONAME ; void CPenInputServerHandler::SendPromptTextToServer(int, struct TFepPromptText const &)
	?SetIcfText@CPenInputServerHandler@@QAEXABUTFepInputContextFieldData@@@Z @ 39 NONAME ; void CPenInputServerHandler::SetIcfText(struct TFepInputContextFieldData const &)
	?SetUiLayout@CPenInputServerHandler@@QAEXH@Z @ 40 NONAME ; void CPenInputServerHandler::SetUiLayout(int)
	?SetDisabledLayout@RPeninputServer@@QAEXH@Z @ 41 NONAME ; void RPeninputServer::SetDisabledLayout(int)
	?ActivatePeninputInNotesL@RPeninputServer@@QAEXXZ @ 42 NONAME ; void RPeninputServer::ActivatePeninputInNotesL(void)
	?DimUiLayout@RPeninputServer@@QAEXH@Z @ 43 NONAME ; void RPeninputServer::DimUiLayout(int)
	?LoseForeground@RPeninputServer@@QAEXXZ @ 44 NONAME ; void RPeninputServer::LoseForeground(void)
	?UpdateAppInfo@RPeninputServer@@QAEXABVTDesC16@@W4TPeninputAppInfo@@@Z @ 45 NONAME ; void RPeninputServer::UpdateAppInfo(class TDesC16 const &, enum TPeninputAppInfo)
	?IsDimmed@RPeninputServer@@QAEHXZ @ 46 NONAME ; int RPeninputServer::IsDimmed(void)
	?DisabledLayout@RPeninputServer@@QAEHXZ @ 47 NONAME ; int RPeninputServer::DisabledLayout(void)
	?RemovePenUiActivationHandler@RPeninputServer@@QAEXPAVMPenUiActivationHandler@@@Z @ 48 NONAME
	?RemovePeninputServerObserver@RPeninputServer@@QAEXPAVMPeninputServerEventHandler@@@Z @ 49 NONAME
	?AutoOpen@RPeninputServer@@QAEHXZ @ 50 NONAME ; int RPeninputServer::AutoOpen(void)
	?SetAutoOpen@RPeninputServer@@QAEXH@Z @ 51 NONAME ; void RPeninputServer::SetAutoOpen(int)
	?UiLayoutSize@RPeninputServer@@QAE?AVTSize@@XZ @ 52 NONAME ; class TSize RPeninputServer::UiLayoutSize(void)
	?BackgroudDefaultOri@RPeninputServer@@QAEXH@Z @ 53 NONAME ; void RPeninputServer::BackgroudDefaultOri(int)
	?PreferredUiMode@RPeninputServer@@QAE?AW4TPluginInputMode@@XZ @ 54 NONAME ; enum TPluginInputMode RPeninputServer::PreferredUiMode(void)
	?SetPreferredUiMode@RPeninputServer@@QAEXW4TPluginInputMode@@@Z @ 55 NONAME ; void RPeninputServer::SetPreferredUiMode(enum TPluginInputMode)
	?ClearTouchUI@RPeninputServer@@QAEXXZ @ 56 NONAME ; void RPeninputServer::ClearTouchUI(void)
	?SetEditorPriority@RPeninputServer@@QAEXH@Z @ 57 NONAME ; void RPeninputServer::SetEditorPriority(int)
	?SetGlobalNotes@RPeninputServer@@QAEXH@Z @ 58 NONAME ; void RPeninputServer::SetGlobalNotes(int)
	?SetInternalPopUp@RPeninputServer@@QAEXH@Z @ 59 NONAME ; void RPeninputServer::SetInternalPopUp(int)
	?SetResourceChange@RPeninputServer@@QAEXH@Z @ 60 NONAME ; void RPeninputServer::SetResourceChange(int)
	?SupportInputMode@RPeninputServer@@QAEHXZ @ 61 NONAME ; int RPeninputServer::SupportInputMode(void)

